@@ -415,22 +415,27 @@ class AssetsAPI(APIClient):
             Union[Asset, AssetList]: Updated asset(s)
 
         Examples:
-
-            Update an asset that you have fetched. This will perform a full update of the asset::
-
-                >>> from cognite.client import CogniteClient
-                >>> c = CogniteClient()
-                >>> asset = c.assets.retrieve(id=1)
-                >>> asset.description = "New description"
-                >>> res = c.assets.update(asset)
-
-            Perform a partial update on a asset, updating the description and adding a new field to metadata::
+            Perform a partial update on an asset, updating the description and adding a new field to metadata::
 
                 >>> from cognite.client import CogniteClient
                 >>> from cognite.client.data_classes import AssetUpdate
                 >>> c = CogniteClient()
                 >>> my_update = AssetUpdate(id=1).description.set("New description").metadata.add({"key": "value"})
-                >>> res = c.assets.update(my_update)
+                >>> res1 = c.assets.update(my_update)
+                >>> # Remove an already set field like so
+                >>> another_update = AssetUpdate(id=1).description.set(None)
+                >>> res2 = c.assets.update(another_update)
+
+            Remove the metadata on an asset::
+                >>> from cognite.client import CogniteClient
+                >>> from cognite.client.data_classes import AssetUpdate
+                >>> c = CogniteClient()
+                >>> my_update = AssetUpdate(id=1).metadata.add({"key": "value"})
+                >>> res1 = c.assets.update(my_update)
+                >>> another_update = AssetUpdate(id=1).metadata.set(None)
+                >>> # The same result can be achieved with:
+                >>> another_update2 = AssetUpdate(id=1).metadata.set({})
+                >>> res2 = c.assets.update(another_update)
 
             Attach labels to an asset::
 
@@ -518,10 +523,12 @@ class AssetsAPI(APIClient):
                 subtree.
 
         Returns:
-            AssetList: The requested assets.
+            AssetList: The requested assets or empty AssetList if asset does not exist.
         """
         utils._auxiliary.assert_exactly_one_of_id_or_external_id(id, external_id)
         asset = self.retrieve(id=id, external_id=external_id)
+        if asset is None:
+            return AssetList([], self._cognite_client)
         subtree = self._get_asset_subtree(AssetList([asset]), current_depth=0, depth=depth)
         subtree._cognite_client = self._cognite_client
         return subtree
